/*
    This is the first of two compilation units that make up a simple C program.

    This file imports a function from the other compilation unit (so the other
    compilation unit can be though of as a libarary for this compilation unit).

    After both compilation units have been compiled, link them together
    with the following lcc-win32 command

      c:\lcc\bin\lcclnk -subsystem console -o cu1.exe cu1.obj cu2.obj

    or with the following gcc command

      c:\mingw\bin\gcc -Wl,--subsystem,console -o cu1.exe cu1.obj cu2.obj

    Try to follow this program every step of the way from being a
    source code file to being a running process. Compare this
    program's assembly language listing with what is inside its
    obj file, with what is inside its exe file, and with what the
    process looks like in virtual memory when it is loaded and running.
    In particular, notice how at each step of the way, more symbols
    are resolved. Pay attention to what each symbol gets resolved to.
*/
#include <stdio.h>
#include <windows.h>

// import an externally defined function
extern int f(int);

int x;  // global variable

int main()
{
   int y;  // local variable

   // call a Windows library function
   x = GetTickCount();

   // call our externally defined function
   y = f(x);

   // call a C Runtime library function
   printf("the value of TickCount = %d\n", y);

   return 0;
}
