/*
    This is the first of three compilation units that make up a simple C program.

    This file imports a global variable and a function from the other compilation units.

    After all three compilation units have been compiled, link them together
    with the following lcc-win32 command

      c:\lcc\bin\lcclnk -subsystem console -o cu1.exe cu1.obj cu2.obj cu3.obj

    or with the following gcc command

      c:\mingw\bin\gcc -g -Wall,--subsystem,console -o cu1.exe cu1.obj cu2.obj cu3.obj

    Note that the order of the obj files is important. Each obj file has
    its unresolved symbols resolved by exports from an obj file further
    to the right in the list.

    Try to follow this program every step of the way from being a
    source code file to being a running process. Compare this
    program's assembly language listing with what is inside its
    obj file, with what is inside its exe file, and with what the
    process looks like in virtual memory when it is loaded and running.
    In particular, notice how at each step of the way, more symbols
    are resolved. Pay attention to what each symbol gets resolved to.
*/
#include <stdio.h>
#include <windows.h>

// import an externally defined global variable
extern int sleepTime;

// import an externally defined function
extern int f(int);

// an initialized global variable (that is not exported)
static int x = 0;

int getSleepTime()
{
   return sleepTime;
}

int main()
{
   // an uninitialized local variable
   int y;

   printf("in compilation unit 1, the address of x is %#.8x\n", &x);
   printf("in compilation unit 1, the address of sleepTime is %#.8x\n", sleepTime);

   // call the external function
   y = f(x);

   while( 1 )
   {
      // call a Windows library function
      x = GetTickCount();
      // call a C Runtime library function
      printf("the value of TickCount = %d\n", x);
      // call our local function
      y = getSleepTime();
      // call another Win32 library function
      Sleep(y);  // sleep for 5 seconds
   }

   return 0;
}
